<?php

namespace Litecms\Casestudy\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Casestudy\Models\Casestudy;

class CasestudyPolicy
{

    /**
     * Determine if the given user can view the casestudy.
     *
     * @param UserPolicy $user
     * @param Casestudy $casestudy
     *
     * @return bool
     */
    public function view(UserPolicy $user, Casestudy $casestudy)
    {
        if ($user->canDo('casestudy.casestudy.view') && $user->isAdmin()) {
            return true;
        }

        return $casestudy->user_id == user_id() && $casestudy->user_type == user_type();
    }

    /**
     * Determine if the given user can create a casestudy.
     *
     * @param UserPolicy $user
     * @param Casestudy $casestudy
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('casestudy.casestudy.create');
    }

    /**
     * Determine if the given user can update the given casestudy.
     *
     * @param UserPolicy $user
     * @param Casestudy $casestudy
     *
     * @return bool
     */
    public function update(UserPolicy $user, Casestudy $casestudy)
    {
        if ($user->canDo('casestudy.casestudy.edit') && $user->isAdmin()) {
            return true;
        }

        return $casestudy->user_id == user_id() && $casestudy->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given casestudy.
     *
     * @param UserPolicy $user
     * @param Casestudy $casestudy
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Casestudy $casestudy)
    {
        return $casestudy->user_id == user_id() && $casestudy->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given casestudy.
     *
     * @param UserPolicy $user
     * @param Casestudy $casestudy
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Casestudy $casestudy)
    {
        if ($user->canDo('casestudy.casestudy.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given casestudy.
     *
     * @param UserPolicy $user
     * @param Casestudy $casestudy
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Casestudy $casestudy)
    {
        if ($user->canDo('casestudy.casestudy.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
